@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Markdown Common Regular Expressions - ~/lib/Regexp/Common/Markdown.pm
-## Version v0.1.1
+## Version v0.1.2
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
 ## Created 2020/08/01
-## Modified 2020/08/10
+## Modified 2020/08/15
 ## 
 ##----------------------------------------------------------------------------
 package Regexp::Common::Markdown;
@@ -19,7 +19,7 @@ BEGIN
     ## We use URI::tel instead of Regexp::Common::tel because its regular expression is antiquated
     ## URI::tel uses the latest rfc3966
     use URI::tel;
-    our $VERSION = 'v0.1.1';
+    our $VERSION = 'v0.1.2';
 
     our $SPACE_RE = qr/[[:blank:]\h]/;
     ## Including vertical space like new lines
@@ -925,6 +925,48 @@ $LIST_TYPE_ORDERED
     ## Ex: {#id1} or {.cl} or {#id.cl.class}
     md_attributes1 => qr/(?<!\\)\{$SPACE_RE*(?<attr>[^\}]*)\}/,
     
+    ## https://regex101.com/r/gF6wVe/1/tests
+    ex_subscript => qr/
+        (?<sub_all>
+            (?:
+                (?<!\\)\~
+                (?<sub_text>
+                    (?>\\[\~[:blank:]\h]|[^\~[:blank:]\h\v])*+
+                )
+                (?<!\\)\~
+            )
+            |
+            (?:     # or the Microsoft way. Beurk
+                \<sub\>
+                (?<sub_text>
+                    ((?!\v).)+
+                )
+                \<\/sub\>
+            )
+        )
+    /x,
+    
+    ## https://regex101.com/r/yAcNcX/1/tests
+    ex_superscript => qr/
+        (?<sup_all>
+            (?:
+                (?<!\\)\^
+                (?<sup_text>
+                    (?>\\[\^[:blank:]\h]|[^\^[:blank:]\h\v])*+
+                )
+                (?<!\\)\^
+            )
+            |
+            (?:     # or the Microsoft way. Beurk
+                \<sup\>
+                (?<sup_text>
+                    ((?!\v).)+
+                )
+                \<\/sup\>
+            )
+        )
+    /x,
+    
     ## https://regex101.com/r/01XCqB/9/tests
     ex_table => qr/
         (?:\n{2,}|\A)
@@ -1101,6 +1143,12 @@ pattern name    => [qw( Markdown ExtLink ) ],
 pattern name    => [qw( Markdown ExtLinkDefinition ) ],
         create  => $REGEXP_EXT->{ex_link_def};
 
+pattern name    => [qw( Markdown ExtSubscript ) ],
+        create  => $REGEXP_EXT->{ex_subscript};
+
+pattern name    => [qw( Markdown ExtSuperscript ) ],
+        create  => $REGEXP_EXT->{ex_superscript};
+
 pattern name    => [qw( Markdown ExtTable ) ],
         create  => $REGEXP_EXT->{ex_table};
 
@@ -1123,13 +1171,13 @@ Regexp::Common::Markdown - Markdown Common Regular Expressions
     while( <> )
     {
         my $pos = pos( $_ );
-        /\G$RE{Markdown}{Header}/gmc       and  print "Found a header at pos $pos\n";
-        /\G$RE{Markdown}{Bold}/gmc       and  print "Found bold text at pos $pos\n";
+        /\G$RE{Markdown}{Header}/gmc   and  print "Found a header at pos $pos\n";
+        /\G$RE{Markdown}{Bold}/gmc     and  print "Found bold text at pos $pos\n";
     }
 
 =head1 VERSION
 
-    v0.1.1
+    v0.1.2
 
 =head1 DESCRIPTION
 
@@ -1591,7 +1639,7 @@ P.S.: If you're wondering, this is an extract from L<Ronsard|https://en.wikipedi
 
 You can see example of this regular expression along with test units here: L<https://regex101.com/r/6VG46H/1/>
 
-There is no capture name. This is basically used like this:
+There is only one capture name: C<br_all>. This is basically used like this:
 
     if( $text =~ /\G$RE{Markdown}{LineBreak}/ )
     {
@@ -2514,6 +2562,62 @@ The link url
 
 You can see also L<Markdown::Parser::LinkDefinition>
 
+=head2 Subscript
+
+    $RE{Markdown}{ExtSubscript}
+
+For example:
+
+    2~10~ is 1024.
+
+would set C<10> as a subscript by the software using this regular expression.
+
+You can see example of this regular expression along with test units here: L<https://regex101.com/r/gF6wVe/1/tests>
+
+The capture names are:
+
+=over 4
+
+=item sub_all
+
+The entire capture of the subscript.
+
+=item sub_text
+
+Contains the text of the subscript
+
+=back
+
+See also: L<Markdown::Parser::Subscript>, L<Pandoc manual|https://pandoc.org/MANUAL.html#superscripts-and-subscripts>
+
+=head2 Superscript
+
+    $RE{Markdown}{ExtSuperscript}
+
+For example:
+
+    2^10^ is 1024.
+
+would set C<10> in superscript by the software using this regular expression.
+
+You can see example of this regular expression along with test units here: L<https://regex101.com/r/yAcNcX/1>
+
+The capture names are:
+
+=over 4
+
+=item sup_all
+
+The entire capture of the superscript.
+
+=item sup_text
+
+Contains the text of the superscript
+
+=back
+
+See also: L<Markdown::Parser::Superscript>, L<Pandoc manual|https://pandoc.org/MANUAL.html#superscripts-and-subscripts>, L<https://facelessuser.github.io/pymdown-extensions/extensions/caret/>
+
 =head2 Table
 
     $RE{Markdown}{ExtTable}
@@ -2560,6 +2664,16 @@ Contains the table caption if set. A table caption, in markdown can be position
 
 Contains the entire header rows
 
+=item table_header1
+
+Contains the first row of the header. This is contained within the capture name I<table_headers>
+
+=item table_header2
+
+Contains the second row, if any, of the header. This is contained within the capture name I<table_headers>
+
+A second is optional and there can be only two rows in the headers as per standards.
+
 =item table_rows
 
 Contains the table body rows
